Index: src/arm/builtins-arm.cc |
diff --git a/src/arm/builtins-arm.cc b/src/arm/builtins-arm.cc |
index 2079e044affb9abf872015ae8cd609bdfdffc6ef..58f4fa3c5c9011dceed9a664e8b5e660258762fc 100644 |
--- a/src/arm/builtins-arm.cc |
+++ b/src/arm/builtins-arm.cc |
@@ -75,12 +75,12 @@ void Builtins::Generate_Adaptor(MacroAssembler* masm, |
// Load the built-in InternalArray function from the current context. |
static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
Register result) { |
// Load the global context. |
__ ldr(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ ldr(result, |
- FieldMemOperand(result, GlobalObject::kGlobalContextOffset)); |
- // Load the InternalArray function from the global context. |
+ FieldMemOperand(result, GlobalObject::kNativeContextOffset)); |
+ // Load the InternalArray function from the native context. |
__ ldr(result, |
MemOperand(result, |
Context::SlotOffset( |
@@ -90,12 +90,12 @@ static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
// Load the built-in Array function from the current context. |
static void GenerateLoadArrayFunction(MacroAssembler* masm, Register result) { |
// Load the global context. |
__ ldr(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ ldr(result, |
- FieldMemOperand(result, GlobalObject::kGlobalContextOffset)); |
- // Load the Array function from the global context. |
+ FieldMemOperand(result, GlobalObject::kNativeContextOffset)); |
+ // Load the Array function from the native context. |
__ ldr(result, |
MemOperand(result, |
Context::SlotOffset(Context::ARRAY_FUNCTION_INDEX))); |
@@ -1405,7 +1405,7 @@ void Builtins::Generate_FunctionCall(MacroAssembler* masm) { |
const int kGlobalIndex = |
Context::kHeaderSize + Context::GLOBAL_INDEX * kPointerSize; |
__ ldr(r2, FieldMemOperand(cp, kGlobalIndex)); |
- __ ldr(r2, FieldMemOperand(r2, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r2, FieldMemOperand(r2, GlobalObject::kNativeContextOffset)); |
__ ldr(r2, FieldMemOperand(r2, kGlobalIndex)); |
__ ldr(r2, FieldMemOperand(r2, GlobalObject::kGlobalReceiverOffset)); |
@@ -1600,7 +1600,7 @@ void Builtins::Generate_FunctionApply(MacroAssembler* masm) { |
const int kGlobalOffset = |
Context::kHeaderSize + Context::GLOBAL_INDEX * kPointerSize; |
__ ldr(r0, FieldMemOperand(cp, kGlobalOffset)); |
- __ ldr(r0, FieldMemOperand(r0, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r0, FieldMemOperand(r0, GlobalObject::kNativeContextOffset)); |
__ ldr(r0, FieldMemOperand(r0, kGlobalOffset)); |
__ ldr(r0, FieldMemOperand(r0, GlobalObject::kGlobalReceiverOffset)); |
@@ -75,12 +75,12 @@ void Builtins::Generate_Adaptor(MacroAssembler* masm, |
static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
Register result) { |
- // Load the global context. |
+ // Load the native context. |
__ ldr(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ ldr(result, |
@@ -90,12 +90,12 @@ static void GenerateLoadInternalArrayFunction(MacroAssembler* masm, |
// Load the built-in Array function from the current context. |
static void GenerateLoadArrayFunction(MacroAssembler* masm, Register result) { |
- // Load the global context. |
+ // Load the native context. |
__ ldr(result, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
__ ldr(result, |